@@ -31,7 +31,7 @@ sub in_reply_to {
     # Adding a related link as advised in the spec
     if (defined $param->{href}) {
       my $link = $self->link(related => $param->{href});
-      $link->attr->{type} = $param->{type} if $param->{type};
+      $link->attrs->{type} = $param->{type} if $param->{type};
     };
 
     $param->{ref} = $ref;
@@ -143,7 +143,7 @@ XML::Loy::Atom::Threading - Threading Extension for Atom
   my $entry = XML::Loy::Atom->new('entry');
 
   # Add threading extension
-  $entry->extension(-Atom::Threading);
+  $entry->extension('XML::Loy::Atom::Threading');
 
   # Add Atom author and id
   $entry->author(name => 'Zoidberg');
@@ -161,7 +161,7 @@ XML::Loy::Atom::Threading - Threading Extension for Atom
   });
 
   # Get threading information
-  print $entry->in_reply_to->[0]->attr('href');
+  print $entry->in_reply_to->[0]->attrs('href');
 
   # Pretty print
   print $entry->to_pretty_xml;
@@ -192,6 +192,7 @@ L<XML::Loy::Atom> and provides additional
 functionality for the work with
 L<Threading|https://www.ietf.org/rfc/rfc4685.txt>.
 
+B<This module is an early release! There may be significant changes in the future.>
 
 =head1 METHODS
 
@@ -206,12 +207,12 @@ from L<XML::Loy> and implements the following new ones.
     type => 'application/xhtml+xml'
   });
 
-  print $entry->in_reply_to->attr('href');
+  print $entry->in_reply_to->attrs('href');
 
 Adds an C<in-reply-to> element to the Atom object or returns it.
 Accepts for adding a universally unique ID for the entry to be referred to,
 and a hash reference containing attributes like C<href>, C<type> and C<source>.
-Will automatically introduce a C<related> link, if a C<href> parameter is given.
+Will automatically introduce a 'related' link, if a C<href> parameter is given.
 Returns the newly added node.
 
 On retrieval, returns the first C<in-reply-to> element.
@@ -224,7 +225,7 @@ On retrieval, returns the first C<in-reply-to> element.
     updated => '2011-08-30T16:16:40Z'
   });
 
-  print $entry->replies->attr('thr:count');
+  print $entry->replies->attrs('thr:count');
 
 Adds a C<link> element with a relation of C<replies> to the atom object
 or returns it.
@@ -261,7 +262,7 @@ L<Mojolicious>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2016, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2011-2013, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
